import os
from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.queue_processing_exception.controller import QueueProcessingExceptionController
from ergondata_executions.controllers.queue_processing_exception.interfaces import *

auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD')
)
api_client = AuthController(auth=auth, logging=True, timeout=20)
controller = QueueProcessingExceptionController(api_client=api_client)

queue_processing_exception_email_recipients = [
    IEmailRecipient(
        email="lorenzo@ergondata.com.br",
        pre_header_name="Lore"
    ),
    IEmailRecipient(
        email="lorenzo@ergondata.com.br",
        pre_header_name="Lore"
    )
]

create_queue_exception_request = CreateQueueProcessingExceptionRequestPayload(
    queue_id="368d2cd7-a173-4667-9cae-90bce75d822c",
    queue_processing_exception_name="Falha ao realizar login no portal da KMM.",
    queue_processing_exception_type="system_error",
    queue_processing_exception_description="Esta exceção é gerada no momento em que o robô naão consegue efetuar login no portal após retentivas.",
    queue_processing_exception_email_integration=True,
    queue_processing_exception_email_recipients=queue_processing_exception_email_recipients
)
create_queue_exception_response = controller.create_queue_processing_exception(params=create_queue_exception_request)


delete_queue_exception_request = DeleteQueueProcessingExceptionRequestPayload(
    queue_processing_exception_id="5d0bee3a-7ef6-49d2-971e-f6ab0001ea83"
)
delete_queue_exception_response = controller.delete_queue_processing_exception(params=delete_queue_exception_request)

get_queue_processing_exceptions_request = GetQueueProcessingExceptionsRequestPayload(
    queue_id="368d2cd7-a173-4667-9cae-90bce75d822c"
)
get_queue_processing_exceptions_response = controller.get_queue_processing_exceptions(params=get_queue_processing_exceptions_request)

emails_recipients = [
    IEmailRecipient(
        email="robert@ergondata.com.br",
        pre_header_name="Lorenzo"
    ),
    IEmailRecipient(
        email="emmanuel@ergondata.com.br",
        pre_header_name="Lorenzo"
    )
]

email_recipients_payload = UpdateEmailRecipientsIntegrationPayload(
    action="overwrite",
    emails=emails_recipients
)

email_integration = UpdateEmailIntegrationPayload(
    active=True,
    recipients=email_recipients_payload
)

update_queue_processing_exception_request = UpdateQueueProcessingExceptionRequestPayload(
    queue_processing_exception_id="509e252a-0fcc-46dc-a0c3-b0af3ae3a75b",
    queue_processing_exception_name="PLANILHA SEM DADOSssss",
    queue_processing_exception_description="Teste de renomeamento",
    queue_processing_exception_email_integration=email_integration
)
update_queue_processing_exception_response = controller.update_queue_processing_exceptions(
    params=update_queue_processing_exception_request
)




from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.task_processing_exception.controller import TaskProcessingExceptionController
from ergondata_executions.controllers.task_processing_exception.interfaces import *

auth = AuthRequestPayload(
    username="",
    password=""
)
api_client = AuthController(auth=auth, logging=True, timeout=20)
controller = TaskProcessingExceptionController(api_client=api_client)

emails_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

create_task_exception_request = CreateTaskProcessingExceptionRequestPayload(
    task_id="e503f7fa-f776-4ed0-b938-5ba5873c2c1c",
    task_processing_exception_status_id="business_exception",
    task_processing_exception_name="Planilha Sharepoint Vazia",
    task_processing_exception_description="Esta exceção é gerada quando o robô baixa a planilha com sucesso mas ela está sem dados.",
    task_processing_exception_email_integration=True,
    task_processing_exception_email_recipients=emails_recipients
)
create_task_exception_response = controller.create_task_processing_exception(params=create_task_exception_request)

get_task_processing_exceptions_request = GetTaskProcessingExceptionsRequestPayload(
    task_id="e503f7fa-f776-4ed0-b938-5ba5873c2c1c"
)
get_task_processing_exceptions_response = controller.get_task_processing_exceptions(params=get_task_processing_exceptions_request)

'''

'''

'''
delete_task_exception_request = DeleteTaskProcessingExceptionRequestPayload(
    task_processing_exception_id="0c1284c6-78c8-42e5-aa7a-b05254b455a3"
)
delete_task_exception_response = controller.delete_task_processing_exception(params=delete_task_exception_request)
'''

'''
'''

emails_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

email_recipients_payload = UpdateEmailRecipientsIntegrationPayload(
    action="add",
    emails=emails_recipients
)

email_integration = UpdateEmailIntegrationPayload(
    active=True,
    recipients=email_recipients_payload
)

update_task_processing_exception_request = UpdateTaskProcessingExceptionRequestPayload(
    task_processing_exception_id="09e476c2-f22c-4f66-b487-161a448fb301",
    task_processing_exception_name="PLANILHA SEM DADOS",
    task_processing_exception_description="Teste de renomeamento",
    task_processing_exception_email_integration=email_integration
)

update_task_processing_exception_response = controller.update_task_processing_exceptions(
    params=update_task_processing_exception_request
)




import sys
import wrapt
from typing import Type
from pydantic import StrictBool, StrictStr, BaseModel
from ergondata_executions.v1.api_exceptions import *
from ergondata_executions.v1.queue_item.interfaces import CreateQueueItemRequestPayload, UpdateQueueItemRequestPayload
from ergondata_executions.v1.auth.interfaces import Performer, Dispatcher, PerformerAndDispatcher


def api_request(
    out_schema: Type[BaseModel],
    exec_token: StrictBool = False,
    queue_item: StrictBool = None,
    log_message: StrictStr = None,
    log_response: StrictBool = True
):
    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):

        self = instance
        if log_message:
            self.api_client.log_info(log_message.format(**kwargs))
        response = wrapped(*args, **kwargs)

        data = out_schema(**response.json())

        if response.status_code == 200:

            if log_response:
                self.api_client.log_info(data)

            if exec_token:

                self.api_client.set_task_execution(
                    exec_token=data.exec_token,
                    task_id=data.data.task.id,
                    task_execution_id=data.data.id
                )

            if queue_item:
                self.api_client.queue_item = data.data

        else:
            self.api_client.log_error(data)

        return data

    return wrapper


def func_logger(log_in: StrictBool = True, log_out: StrictBool = True, log_args: StrictBool = True):
    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):

        self = instance
        ergon = self.ergon
        function_id = wrapped.__name__

        if log_in:

            arg_str = ', '.join(f"{k}={v}" for k, v in zip(wrapped.__code__.co_varnames, args))
            arg_str += ', '.join(f"{k}={v}" for k, v in kwargs.items())

            if arg_str and log_args:
                message = f"Stepped in {function_id} with arguments: {arg_str}"
            else:
                message = f"Stepped in {function_id}"

            ergon.write_tk_exec_log(
                message=message,
                level="info",
                task_step_id=function_id
            )

        result = wrapped(*args, **kwargs)

        if log_out:
            ergon.write_tk_exec_log(
                message=f"Stepped out {function_id}",
                level="info",
                task_step_id=function_id
            )

        return result

    return wrapper

@wrapt.decorator
def run_decorator(wrapped, instance, args, kwargs):

    self = instance

    self.ergon.write_tk_exec_log(
        message="Running main method",
        task_step_id="main",
        level="info"
    )

    try:
        result = wrapped(*args, **kwargs)
        self.ergon.update_task_execution(processing_status_id="success")
        self.ergon.write_tk_exec_log(message="Task execution finished")
    except TaskException:
        sys.exit("Task execution failed due to TaskException")
    except BaseException as e:
        raise TaskFailed(ergon=self.ergon, processing_status_message=str(e))
    return result

def run(wrapped_function=None):
    # Check if the decorator is called without parentheses
    if wrapped_function is None:
        return run_decorator
    else:
        return run_decorator(wrapped_function)


@wrapt.decorator
def dispatch_queue_item_decorator(wrapped, instance, args, kwargs):

    self = instance

    try:

        # Access the item argument if available
        result: CreateQueueItemRequestPayload = wrapped(*args, **kwargs)

        self.ergon.create_queue_item(
            queue_id=self.ergon.api_client.config.task_exec_config.target_queue_id,
            processing_status_message=result.processing_status_message,
            payload=result.payload,
            external_id=result.external_id,
            processing_priority_id=result.processing_priority_id,
            processing_status_id=result.processing_status_id
        )
        self.ergon.write_tk_exec_log(message="Finished dispatching item")
        return result

    except DispatcherQIException:
        self.ergon.write_tk_exec_log(message=f"Queue item raised an exception", level="error")
    except DispatcherQISysError:
        self.ergon.write_tk_exec_log(message=f"Queue item raised a system exception", level="error")
    except DispatcherQIBusException:
        self.ergon.write_tk_exec_log(message=f"Queue item raised a business exception", level="error")
    except BaseException as e:
        self.ergon.write_tk_exec_log(message=f"Queue item raised an unknown error {e}", level="error")


def create_queue_item(wrapped_function=None):
    # Check if the decorator is called without parentheses
    if wrapped_function is None:
        return dispatch_queue_item_decorator
    else:
        return dispatch_queue_item_decorator(wrapped_function)

@wrapt.decorator
def get_queue_item_decorator(wrapped, instance, args, kwargs):

    self = instance
    queue_id = self.ergon.api_client.config.task_exec_config.source_queue_id
    self.ergon.write_tk_exec_log(message=f"Reading queue items from {queue_id}")

    while True:

        try:

            queue_item = self.ergon.get_queue_item(queue_id=queue_id)

            if not queue_item.data:
                self.ergon.write_tk_exec_log(message=f"No more queue items to read from {queue_id}")
                break

            result: UpdateQueueItemRequestPayload = wrapped(queue_item, queue_id)

            self.ergon.update_queue_item(
                queue_id=queue_id,
                queue_item_id=queue_item.data.id,
                processing_status_id="success",
                processing_status_message=result.processing_status_message,
                payload=result.payload
            )

            self.ergon.write_tk_exec_log(message=f"Queue item {queue_item.data.id} processed with success")

        except PerformerQIException:
            self.ergon.write_tk_exec_log(message=f"Queue item raised an exception", level="error")
        except PerformerQISysError:
            self.ergon.write_tk_exec_log(message=f"Queue item raised a system exception", level="error")
        except PerformerQIBusException:
            self.ergon.write_tk_exec_log(message=f"Queue item raised a business exception", level="error")
        except BaseException as e:
            self.ergon.update_queue_item(
            queue_item_id=self.ergon.api_client.queue_item.id,
            processing_status_id="system_error",
            processing_status_message=str(e),
            queue_id=queue_id
        )




def get_next_item(wrapped_function=None):
    # Check if the decorator is called without parentheses
    if wrapped_function is None:
        return get_queue_item_decorator
    else:
        return get_queue_item_decorator(wrapped_function)


from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.queue.controller import QueueController
from ergondata_executions.controllers.queue.interfaces import *



import os

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.queue.controller import QueueController
from ergondata_executions.controllers.queue.interfaces import *

auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD')
)
api_client = AuthController(auth=auth, logging=True, timeout=20)
controller = QueueController(api_client=api_client)

''' CREATE QUEUE '''

queue_item_created_email_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

queue_item_started_email_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

queue_item_succeeded_email_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

queue_item_failed_email_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

create_queue_request = CreateQueueRequestPayload(
    process_id="324c8d35-9ca9-484d-ac71-d372b8f82019",
    queue_name="Quitação de Contrato",
    queue_description="Items para quitacao de contrato",
    allow_to_include_repeated_queue_item=False,
    queue_item_max_retries_within_execution=1,
    queue_item_max_retries_outside_execution=5,
    queue_item_created_email_integration=True,
    queue_item_started_email_integration=True,
    queue_item_succeeded_email_integration=True,
    queue_item_failed_email_integration=True,
    queue_item_created_email_recipients=queue_item_created_email_recipients,
    queue_item_failed_email_recipients=queue_item_failed_email_recipients,
    queue_item_succeeded_email_recipients=queue_item_succeeded_email_recipients,
    queue_item_started_email_recipients=queue_item_started_email_recipients
)
create_queue_response = controller.create_queue(params=create_queue_request)


''' DELETE QUEUE '''
delete_queue_request = DeleteQueueRequestPayload(
    queue_id="3b5c53b3-a28c-4243-9b34-fd1f0614fb4b"
)
delete_queue_response = controller.delete_queue(params=delete_queue_request)


''' GET QUEUES '''

get_queues_request = GetQueuesRequestPayload(
    process_id="324c8d35-9ca9-484d-ac71-d372b8f82019"
)
get_queues_response = controller.get_queues(params=get_queues_request)


''' UPDATE QUEUE '''

queue_item_created_email_recipients = [
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

queue_item_created_email_recipients_integration = UpdateQueueEmailRecipientsPayload(
    action="remove",
    emails=queue_item_created_email_recipients
)

queue_item_created_email_integration = UpdateQueueEmailIntegrationPayload(
    active=False,
    recipients=queue_item_created_email_recipients_integration
)

queue_item_started_email_recipients = [
    IEmailRecipient(
        email="jorge.vossos@ergondata.com.br",
        pre_header_name="Jorge"
    )
]

queue_item_started_email_recipients_integration = UpdateQueueEmailRecipientsPayload(
    action="add",
    emails=queue_item_started_email_recipients
)

queue_item_started_email_integration = UpdateQueueEmailIntegrationPayload(
    active=True,
    recipients=queue_item_started_email_recipients_integration
)

queue_item_succeeded_email_recipients = [
    IEmailRecipient(
        email="jorge.vossos@ergondata.com.br",
        pre_header_name="Jorge"
    )
]

queue_item_succeeded_email_recipients_integration = UpdateQueueEmailRecipientsPayload(
    action="add",
    emails=queue_item_succeeded_email_recipients
)

queue_item_succeeded_email_integration = UpdateQueueEmailIntegrationPayload(
    active=True,
    recipients=queue_item_succeeded_email_recipients_integration
)

queue_item_failed_email_recipients = [
    IEmailRecipient(
        email="jorge.vossos@ergondata.com.br",
        pre_header_name="Jorge"
    )
]

queue_item_failed_email_recipients_integration = UpdateQueueEmailRecipientsPayload(
    action="overwrite",
    emails=queue_item_failed_email_recipients
)

queue_item_failed_email_integration = UpdateQueueEmailIntegrationPayload(
    active=True,
    recipients=queue_item_failed_email_recipients_integration
)

email_integration = UpdateQueueEmailIntegration(
    queue_item_created=queue_item_created_email_integration,
    queue_item_started=queue_item_started_email_integration,
    queue_item_succeeded=queue_item_succeeded_email_integration,
    queue_item_failed=queue_item_failed_email_integration,
)

update_queue_request = UpdateQueueRequestPayload(
    queue_id="f3cf9181-b43a-4d59-9a6a-e33cc8f13382",
    queue_name="Teste Rename Fila",
    allow_to_include_repeated_queue_item=True,
    queue_item_max_retries_within_execution=10,
    queue_item_max_retries_outside_execution=20,
    email_integration=email_integration
)
update_queue_response = controller.update_queues(params=update_queue_request)


from ergondata_executions.interfaces import *

class WorkerUser(BaseModel):
    id: StrictStr
    friendly_name: StrictStr = Field(alias="first_name")
    client: Client
    type: UserType
    created_at: datetime


class Worker(BaseModel):
    id: StrictStr
    user: WorkerUser
    created_at: datetime
    updated_at: datetime


class CreateWorkerResponsePayload(APIBaseResponse):
    data: Optional[Worker] = None


class DeleteWorkerResponsePayload(APIBaseResponse):
    worker_id: StrictStr


class GetWorkersResponsePayload(APIBaseResponse):
    data: list[Worker]



import sys
from pydantic import StrictStr
from typing import Optional, Any


class TaskException(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        task_exception_id: StrictStr = None,
        processing_status_message: StrictStr = None,
    ):

        ergon.update_task_execution(
            task_exception_id=task_exception_id,
            processing_status_message=str(processing_status_message),
        )

        super().__init__(self)


class TaskFailed(Exception):

    def __init__(
        self,
        ergon,
        processing_status_message: Optional[StrictStr] = None,
    ):

        ergon.update_task_execution(
            processing_status_id="system_error",
            processing_status_message=processing_status_message
        )
        sys.exit(f"Task failed due to generic unknown error {processing_status_message}")


class DispatcherQIException(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        processing_exception_id: StrictStr,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None,
    ):

        ergon.create_queue_item(
            queue_id=ergon.api_client.config.task_exec_config.target_queue_id,
            external_id=external_id,
            payload=payload,
            processing_exception_id=processing_exception_id,
            processing_status_message=str(processing_status_message)
        )

        super().__init__(self)


class PerformerQIException(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        queue_item_id: StrictStr,
        processing_exception_id: StrictStr,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None,
    ):

        ergon.update_queue_item(
            queue_id=ergon.api_client.config.task_exec_config.source_queue_id,
            queue_item_id=queue_item_id,
            external_id=external_id,
            payload=payload,
            processing_exception_id=processing_exception_id,
            processing_status_message=str(processing_status_message)
        )

        super().__init__(self)


class DispatcherQISysError(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None
    ):

        ergon.create_queue_item(
            queue_id=ergon.api_client.config.task_exec_config.target_queue_id,
            external_id=external_id,
            payload=payload,
            processing_status_id="system_error",
            processing_status_message=str(processing_status_message)
        )

        super().__init__(self)


class PerformerQISysError(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        queue_item_id: StrictStr,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None
    ):

        ergon.update_queue_item(
            queue_item_id=queue_item_id,
            queue_id=ergon.api_client.config.task_exec_config.source_queue_id,
            external_id=external_id,
            payload=payload,
            processing_status_id="system_error",
            processing_status_message=str(processing_status_message)
        )

        super().__init__(self)


class DispatcherQIBusException(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None
    ):

        ergon.create_queue_item(
            queue_id=ergon.api_client.config.task_exec_config.target_queue_id,
            external_id=external_id,
            payload=payload,
            processing_status_id="business_exception",
            processing_status_message=processing_status_message
        )

        super().__init__(self)



class PerformerQIBusException(Exception):

    ergon = None

    def __init__(
        self,
        ergon,
        payload,
        queue_item_id: StrictStr,
        external_id: StrictStr = None,
        processing_status_message: StrictStr = None
    ):

        ergon.update_queue_item(
            queue_item_id=queue_item_id,
            queue_id=ergon.api_client.config.task_exec_config.source_queue_id,
            external_id=external_id,
            payload=payload,
            processing_status_id="business_exception",
            processing_status_message=processing_status_message
        )

        super().__init__(self)


import logging
import os
import uuid
from typing import Literal, Union

class APILogger:
    def __init__(
        self,
        enable_logs: bool = True,
        log_file_path: str = 'logs',
        log_level: Literal["info", "debug", "error", "warning"] = "debug"
    ):
        self.enable_logs = enable_logs
        self.log_file_path = log_file_path
        self.logger = logging.getLogger(__name__)
        self.log_level = log_level

        # Configure the logger to write to a file
        self._configure_file_handler()

        # Configure a console handler
        console_handler = logging.StreamHandler()
        formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
        console_handler.setFormatter(formatter)
        self.logger.addHandler(console_handler)

        # Set the logger level to DEBUG to capture all messages

        if self.log_level == "debug":
            self.logger.setLevel(logging.DEBUG)
        elif self.log_level == "info":
            self.logger.setLevel(logging.INFO)
        elif self.log_level == "warning":
            self.logger.setLevel(logging.WARNING)
        elif self.log_level == "error":
            self.logger.setLevel(logging.ERROR)
        else:
            self.logger.setLevel(logging.DEBUG)

    def _get_log_file_path(self):
        # Generate a unique filename using UUID
        log_filename = f"{uuid.uuid4()}.txt"
        return os.path.join(self.log_file_path, log_filename)

    def _configure_file_handler(self):

        if not self.log_file_path:
            return

        log_file_path = self._get_log_file_path()
        file_handler = logging.FileHandler(log_file_path)
        formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
        file_handler.setFormatter(formatter)
        self.logger.addHandler(file_handler)

    def log_error(self, message):
        if self.enable_logs:
            self.logger.error(message)

    def log_info(self, message):
        if self.enable_logs:
            self.logger.info(message)

    def log_warning(self, message):
        if self.enable_logs:
            self.logger.warning(message)


    def log(self, message, level: Literal["warning", "info", "error"] = "info"):
        if level == "warning":
            self.logger.log(msg=message, level=logging.WARNING)
        elif level == "info":
            self.logger.log(msg=message, level=logging.INFO)
        elif level == "error":
            self.logger.log(msg=message, level=logging.ERROR)
        else:
            pass



from ergondata_executions.interfaces import *
from ergondata_executions.v1.queue.interfaces import Queue, QueueItemStatus

class QueuePriority(BaseModel):
    id: StrictStr
    name: StrictStr
    description: StrictStr
    queue: Queue
    created_at: datetime
    updated_at: datetime


class CreateQueuePriorityRequestPayload(BaseModel):
    name: StrictStr
    description: StrictStr


class UpdateQueuePriorityRequestPayload(BaseModel):
    name: StrictStr
    description: StrictStr

class CreateQueuePriorityResponsePayload(APIBaseResponse):
    data: Optional[QueuePriority] = None

class DeleteQueuePriorityResponsePayload(APIBaseResponse):
    queue_priority_id: Optional[StrictStr] = None


class GetQueuePrioritiesResponsePayload(APIBaseResponse):
    data: List[QueuePriority]

class UpdateQueuePriorityResponsePayload(CreateQueuePriorityResponsePayload):
    data: Optional[QueuePriority] = None


import requests

from ergondata_executions.v1.auth.controller import AuthController
from ergondata_executions.v1.queue_item.interfaces import *
from ergondata_executions.v1.decorators import *

class QueueItemController:

    CREATE_QUEUE_ITEM_URL = "queues/{0}/items"
    GET_QUEUE_ITEM_URL = "queues/{0}/item"
    DELETE_QUEUE_EXCEPTION_URL = "queues/{0}/exceptions/{1}"
    UPDATE_QUEUE_ITEM_URL = "queues/{0}/items/{1}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    @api_request(log_message="Creating queue item", out_schema=CreateQueueItemResponsePayload)
    def create_queue_item(
        self,
        queue_id: StrictStr,
        payload: Any,
        external_id: StrictStr = None,
        processing_status_id: StrictStr = "pending",
        processing_exception_id: StrictStr = None,
        processing_priority_id: StrictStr = None,
        processing_status_message: StrictStr = None,

    ) -> CreateQueueItemResponsePayload:
        res: Any = requests.post(
            url=f"{self.api_client.ROOT_URL}{self.CREATE_QUEUE_ITEM_URL.format(queue_id)}",
            json=CreateQueueItemRequestPayload(
                external_id=external_id,
                payload=payload,
                processing_status_id=processing_status_id,
                processing_priority_id=processing_priority_id,
                processing_status_message=processing_status_message,
                processing_exception_id=processing_exception_id
            ).model_dump(),
            headers=self.api_client.exec_header if self.api_client.exec_token else self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Getting queue item", out_schema=GetQueueItemResponsePayload, queue_item=True)
    def get_queue_item(
        self,
        queue_id: StrictStr,
        external_id: StrictStr = None,
        priority_id__in: List[StrictStr] = None
    ) -> GetQueueItemResponsePayload:
        res: Any = requests.get(
            url=f"{self.api_client.ROOT_URL}{self.GET_QUEUE_ITEM_URL.format(queue_id)}",
            params=GetQueueItemQueryParams(
                external_id=external_id,
                priority_id__in=priority_id__in
            ).model_dump(),
            headers=self.api_client.exec_header if self.api_client.exec_token else self.api_client.auth_header
        )
        return res

    @api_request(log_message="Updating queue item", out_schema=UpdateQueueItemResponsePayload)
    def update_queue_item(
        self,
        queue_item_id: StrictStr,
        queue_id: StrictStr,
        payload: Any = None,
        processing_status_id: StrictStr = None,
        processing_exception_id: StrictStr = None,
        processing_status_message: StrictStr = None,
    ) -> UpdateQueueItemResponsePayload:
        res: Any = requests.put(
            url=f"{self.api_client.ROOT_URL}{self.UPDATE_QUEUE_ITEM_URL.format(queue_id, queue_item_id)}",
            json=UpdateQueueItemRequestPayload(
                payload=payload,
                processing_status_id=processing_status_id,
                processing_exception_id=processing_exception_id,
                processing_status_message=processing_status_message
            ).model_dump(),
            headers=self.api_client.exec_header if self.api_client.exec_token else self.api_client.auth_header
        )
        return res


from ergondata_executions.interfaces import *
from ergondata_executions.v1.queue.interfaces import Queue, QueueItemStatus

class QueueException(BaseModel):
    id: StrictStr
    name: StrictStr
    description: StrictStr
    queue: Queue
    queue_item_status: QueueItemStatus
    created_at: datetime
    updated_at: datetime


class CreateQueueExceptionRequestPayload(BaseModel):
    name: StrictStr
    description: StrictStr
    queue_item_status_id: Literal["success", "business_exception", "system_error"]
    reprocess_within: Optional[StrictBool] = False
    reprocess_outside: Optional[StrictBool] = False


class UpdateQueueExceptionRequestPayload(CreateQueueExceptionRequestPayload):
    pass

class CreateQueueExceptionResponsePayload(APIBaseResponse):
    data: Optional[QueueException] = None

class DeleteQueueExceptionResponsePayload(APIBaseResponse):
    process_id: Optional[StrictStr] = None


class GetQueueExceptionsResponsePayload(APIBaseResponse):
    data: List[QueueException]

class UpdateQueueExceptionResponsePayload(CreateQueueExceptionResponsePayload):
    data: Optional[QueueException] = None


import os
from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.task.controller import TaskController
from ergondata_executions.controllers.task.interfaces import *


auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD')
)

api_client = AuthController(auth=auth, logging=True, timeout=20)

task_controller = TaskController(api_client=api_client)

''' CREATE TASK '''
task_started_email_recipients = [
    IEmailRecipient(
        email="lucas.leite@ergondata.com.br",
        pre_header_name="Lucas"
    ),
    IEmailRecipient(
        email="lorenzo@ergondata.com.br",
        pre_header_name="Lorenzo"
    ),
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

task_succeeded_email_recipients = [
    IEmailRecipient(
        email="lucas.leite@ergondata.com.br",
        pre_header_name="Lucas"
    ),
    IEmailRecipient(
        email="lorenzo@ergondata.com.br",
        pre_header_name="Lorenzo"
    ),
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

task_failed_emailed_recipients = [
    IEmailRecipient(
        email="lucas.leite@ergondata.com.br",
        pre_header_name="Lucas"
    ),
    IEmailRecipient(
        email="lorenzo@ergondata.com.br",
        pre_header_name="Lorenzo"
    ),
    IEmailRecipient(
        email="daniel.vossos@ergondata.com.br",
        pre_header_name="Daniel"
    )
]

create_task_request = CreateTaskRequestPayload(
    process_id="324c8d35-9ca9-484d-ac71-d372b8f82019",
    task_name="Perfomer Geracão de Contrato",
    task_description="Essa task le os dados da fila de geraçaão de contrato e tenta gerar o número de contrato. Se conseguir, coloca na fila de quitação.",
    task_type="performer-and-dispatcher",
    task_started_email_integration=True,
    task_succeeded_email_integration=True,
    task_failed_email_integration=True,
    task_started_email_recipients=task_started_email_recipients,
    task_succeeded_email_recipients=task_succeeded_email_recipients,
    task_failed_email_recipients=task_failed_emailed_recipients
)

create_task_response = task_controller.create_task(params=create_task_request)

''' DELETE TASK '''
delete_task_request = DeleteTaskRequestPayload(
    task_id='d3547abb-0548-40eb-90e6-2170058b4a91'
)
delete_task_response = task_controller.delete_task(params=delete_task_request)


''' GET TASKS '''
get_tasks_request = GetTasksRequestPayload(process_id="324c8d35-9ca9-484d-ac71-d372b8f82019")
get_tasks_response = task_controller.get_tasks(params=get_tasks_request)


''' UPDATE TASK '''
task_failed_emails = [
    IEmailRecipient(
        email="emmanuel@ergondata.com.br",
        pre_header_name="Emmanuel"
    ),
    IEmailRecipient(
        email="maria@ergondata.com.br",
        pre_header_name="Maria"
    ),
]

task_failed_email_recipients_payload = UpdateTaskEmailRecipientsPayload(
    action="add",
    emails=task_failed_emails
)

task_failed_email_integration = UpdateTaskEmailIntegrationPayload(
    active=True,
    recipients=task_failed_email_recipients_payload
)

task_succeeded_emails = [
    IEmailRecipient(
        email="emmanuel@ergondata.com.br",
        pre_header_name="Emmanuel"
    ),
    IEmailRecipient(
        email="maria@ergondata.com.br",
        pre_header_name="Maria"
    ),
]

task_succeeded_email_recipients_payload = UpdateTaskEmailRecipientsPayload(
    action="remove",
    emails=task_succeeded_emails
)

task_succeeded_email_integration = UpdateTaskEmailIntegrationPayload(
    active=True,
    recipients=task_succeeded_email_recipients_payload
)

task_started_emails = [
    IEmailRecipient(
        email="emmanuel@ergondata.com.br",
        pre_header_name="Emmanuel"
    ),
    IEmailRecipient(
        email="maria@ergondata.com.br",
        pre_header_name="Maria"
    ),
]

task_started_email_recipients_payload = UpdateTaskEmailRecipientsPayload(
    action="overwrite",
    emails=task_started_emails
)

task_started_email_integration = UpdateTaskEmailIntegrationPayload(
    active=True,
    recipients=task_started_email_recipients_payload
)

task_email_integration = UpdateTaskEmailIntegration(
    task_started=task_started_email_integration,
    task_succeeded=task_succeeded_email_integration,
    task_failed=task_failed_email_integration
)

update_task_request = UpdateTaskRequestPayload(
    task_id="367a9289-b9d2-4bea-929a-4ce5e6c539ac",
    task_name="Novo processo",
    task_description="Teste de rename",
    task_email_integration=task_email_integration
)
update_task_response = task_controller.update_tasks(params=update_task_request)










from datetime import datetime

from pydantic import BaseModel, StrictStr, StrictBool, Field, StrictInt
from typing import Union, Optional, Literal, List, Any
from functools import wraps

class APIBaseResponse(BaseModel):
    status: Optional[Literal["success", "error"]] = "error"
    message: Optional[StrictStr] = None
    error_messages: Optional[Union[List[Any], Any]] = None
    validation_errors: Optional[Any] = Field(alias="detail", default=None)

class IEmailRecipient(BaseModel):
    email: StrictStr
    pre_header_name: StrictStr


class IEmailIntegrationData(BaseModel):
    active: StrictBool
    recipients: Union[List[IEmailRecipient], None] = None


class UpdateEmailRecipientsPayload(BaseModel):
    action: Literal["overwrite", "add", "remove"]
    emails: List[IEmailRecipient]


class WhatsappRecipient(BaseModel):
    country_code: StrictStr
    country_dial_code: StrictInt
    country_name: StrictStr
    phone_number: StrictInt


def input_model(func):
    @wraps(func)
    def wrapper(self, **kwargs):
        model_fields = func.__annotations__
        validated_payload = {}

        for field_name, field_type in model_fields.items():
            if field_name in kwargs:
                validated_payload[field_name] = field_type(kwargs[field_name])

        return func(self, validated_payload)

    return wrapper


class Client(BaseModel):
    id: StrictStr
    name: StrictStr
    created_at: datetime
    updated_at: datetime


class UserType(BaseModel):
    id: Literal["client-owner", "workspace-member", "process-member", "worker"]
    name: StrictStr


import os
from dotenv import load_dotenv

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.database.controller import DBController
from ergondata_executions.controllers.database.interfaces import *

load_dotenv()

auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD'),
    client_id=os.getenv('CLIENT_OWNER_API_CLIENT_ID')
)

api_client = AuthController(auth=auth, logging=True, timeout=20)
db_controller = DBController(api_client)

'''
get_dbs_response = db_controller.get_databases()

create_database_request = CreateDatabaseRequestPayload(
    database_name="Operaçoes"
)
create_db_response = db_controller.create_database(params=create_database_request)

delete_database_request = DeleteDatabaseRequestPayload(
    database_id='84da07ab-e46c-4f1b-8495-90fc78977b17'
)
delete_database_response = db_controller.delete_database(params=delete_database_request)

update_database_request = UpdateDatabaseRequestPayload(
    database_id='',
    database_name=''
)
update_database_response = db_controller.update_database(params=update_database_request)
'''
create_db_member_request = CreateDatabaseMemberRequestPayload(
    database_id="2cfef6f3-22c6-4400-bb13-7d95850f4bef",
    database_member_email="lorenzo@ergondata.com.br",
    database_member_username="lorenzo.freto"
)
create_db_member_response = db_controller.create_database_member(params=create_db_member_request)

get_db_members_request = GetDatabaseMembersRequestPayload(
    database_id="2cfef6f3-22c6-4400-bb13-7d95850f4bef"
)
get_db_members_response = db_controller.get_database_members(params=get_db_members_request)

delete_database_member_request = DeleteDatabaseMemberRequestPayload(
    database_member_id="c54552c3-0475-4c00-a1dd-7c9baa067085"
)
delete_database_member_response = db_controller.delete_database_member(params=delete_database_member_request)





import os

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.process.controller import ProcessController
from ergondata_executions.controllers.process.interfaces import *

auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD')
)

api_client = AuthController(auth=auth, logging=True, timeout=20)
controller = ProcessController(api_client)

create_process_request = CreateProcessRequestPayload(
    database_id="2cfef6f3-22c6-4400-bb13-7d95850f4bef",
    process_title="JJ-Mendes",
    process_description="Este processo é divido em três task para efetuar o processo do jj mendes até o final."
)
create_process_response = controller.create_process(params=create_process_request)

delete_process_request = DeleteProcessRequestPayload(
    process_id="0cce1515-c965-42f7-a1d0-c360e7875bb9"
)
delete_process_response = controller.delete_process(params=delete_process_request)

get_processes_request = GetProcessesRequestPayload(
    database_id="2cfef6f3-22c6-4400-bb13-7d95850f4bef"
)
get_processes_response = controller.get_processes(params=get_processes_request)


import os
from dotenv import load_dotenv

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.worker.controller import WorkerController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload
from ergondata_executions.controllers.worker.interfaces import *


load_dotenv()

auth = AuthRequestPayload(
    username=os.getenv('CLIENT_OWNER_API_USERNAME'),
    password=os.getenv('CLIENT_OWNER_API_PASSWORD'),
    client_id=os.getenv('CLIENT_OWNER_API_CLIENT_ID')
)

api_client = AuthController(auth=auth, logging=True, timeout=20)
controller = WorkerController(api_client=api_client)

create_worker_request = CreateWorkerRequestPayload(worker_first_name="worker-01")
# create_worker_response = controller.create_worker(params=create_worker_request)

'''
delete_worker_request = DeleteWorkerRequestPayload(
    worker_id=create_worker_response.worker_id
)
delete_worker_response = controller.delete_worker(params=delete_worker_request)
'''

get_workers_request = controller.get_workers()



import requests

from ergondata_executions.v1.auth.controller import AuthController
from ergondata_executions.v1.queue_exception.interfaces import *
from ergondata_executions.v1.decorators import *

class QueueExceptionController:

    CREATE_QUEUE_EXCEPTION_URL = "queues/{0}/exceptions"
    GET_QUEUE_EXCEPTIONS_URL = "queues/{0}/exceptions"
    DELETE_QUEUE_EXCEPTION_URL = "queues/{0}/exceptions/{1}"
    UPDATE_QUEUE_EXCEPTION_URL = "queues/{0}/exceptions/{1}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    @api_request(log_message="Creating queue_exception {name}", out_schema=CreateQueueExceptionResponsePayload)
    def create_queue_exception(
        self,
        queue_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        queue_item_status_id: Literal["success", "business_exception", "system_error"],
        reprocess_within: StrictInt = 0,
        reprocess_outside: StrictInt = 0,
    ) -> CreateQueueExceptionResponsePayload:
        res: Any = requests.post(
            url=f"{self.api_client.ROOT_URL}{self.CREATE_QUEUE_EXCEPTION_URL.format(queue_id)}",
            json=CreateQueueExceptionRequestPayload(
                name=name,
                description=description,
                queue_item_status_id=queue_item_status_id,
                reprocess_within=reprocess_within,
                reprocess_outside=reprocess_outside
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Deleting queue_exception {queue_exception_id}", out_schema=DeleteQueueExceptionResponsePayload)
    def delete_queue_exception(
        self,
        queue_id: StrictStr,
        queue_exception_id: StrictStr
    ) -> DeleteQueueExceptionResponsePayload:
        res: Any = requests.delete(
            url=f"{self.api_client.ROOT_URL}{self.DELETE_QUEUE_EXCEPTION_URL.format(queue_id, queue_exception_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Getting queue_exceptions", out_schema=GetQueueExceptionsResponsePayload)
    def get_queue_exceptions(self, queue_id: StrictStr) -> GetQueueExceptionsResponsePayload:
        res: Any = requests.get(
            url=f"{self.api_client.ROOT_URL}{self.GET_QUEUE_EXCEPTIONS_URL.format(queue_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Updating queue_exception {name}", out_schema=UpdateQueueExceptionResponsePayload)
    def update_queue_exception(
        self,
        queue_exception_id: StrictStr,
        queue_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        queue_item_status_id: Literal["success", "business_exception", "system_error"],
        reprocess_within: StrictInt = 0,
        reprocess_outside: StrictInt = 0,
    ) -> UpdateQueueExceptionResponsePayload:
        res: Any = requests.put(
            url=f"{self.api_client.ROOT_URL}{self.UPDATE_QUEUE_EXCEPTION_URL.format(queue_id, queue_exception_id)}",
            json=UpdateQueueExceptionRequestPayload(
                name=name,
                description=description,
                queue_item_status_id=queue_item_status_id,
                reprocess_within=reprocess_within,
                reprocess_outside=reprocess_outside
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res



from datetime import datetime
from ergondata_executions.interfaces import *
from ergondata_executions.v1.workspace.interfaces import Workspace
from ergondata_executions.v1.process.interfaces import Process

class TaskStatus(BaseModel):
    id: Literal["success", "reset", "released", "business_exception", "system_error", "processing"]
    name: StrictStr


class Task(BaseModel):
    id: StrictStr
    name: StrictStr
    description: StrictStr
    process: Process
    created_at: datetime
    updated_at: datetime


class CreateTaskRequestPayload(BaseModel):
    name: StrictStr
    description: StrictStr
    process_id: StrictStr
    task_type_id: Literal["dispatcher", "performer", "performer-and-dispatcher"]
    cron_schedule_expression: StrictStr
    cron_schedule_expression_description: StrictStr
    reset_ongoing_execution: StrictBool = False
    release_ongoing_execution: StrictBool = False
    timezone: StrictStr

class UpdateTaskRequestPayload(CreateTaskRequestPayload):
    pass

class CreateTaskResponsePayload(APIBaseResponse):
    data: Optional[Task] = None

class DeleteTaskResponsePayload(APIBaseResponse):
    task_id: Optional[StrictStr] = None


class GetTasksResponsePayload(APIBaseResponse):
    data: List[Task]

class UpdateTaskResponsePayload(CreateTaskResponsePayload):
    data: Workspace


import os
from dotenv import load_dotenv

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import AuthRequestPayload

from ergondata_executions.controllers.task_execution.controller import TaskExecutionController
from ergondata_executions.controllers.task_execution.interfaces import *

from ergondata_executions.controllers.queue_item.controller import QueueItemController
from ergondata_executions.controllers.queue_item.interfaces import *

from ergondata_executions.controllers.task_execution_log.controller import TaskExecutionLogController
from ergondata_executions.controllers.task_execution_log.interfaces import *

load_dotenv()
'''
auth = AuthRequestPayload(
    username=os.getenv('WORKER_API_USERNAME'),
    password=os.getenv('WORKER_API_PASSWORD'),
    client_id=os.getenv('WORKER_API_CLIENT_ID')
)

api_client = AuthController(auth=auth, timeout=1000)
controller = TaskExecutionController(api_client=api_client)

create_task_execution_request = CreateTaskExecutionRequestPayload(
    task_id="058537b1-59ae-44f6-b4cc-bd3c14849158",
    dev_mode=True
)
create_task_execution_response = controller.create_task_execution(create_task_execution_request)

if create_task_execution_response.status == "error":
    reset_task_execution_response = controller.reset_task_execution()
    create_task_execution_response = controller.create_task_execution(create_task_execution_request)

qi_controller = QueueItemController(api_client=api_client)

for i in range(0, 10):
    create_queue_item_request = CreateQueueItemRequestPayload(
        external_id="daniel.vossos@ergondata.com.br-xxx",
        queue_id="27b5213b-84eb-4e43-a935-6a261105c520",
        payload=[
            {"nome": "Daniel", "email": "daniel.vossos@ergondata.com.br"},
            {"nome": "Daniel", "email": "daniel.vossos@ergondata.com.br"},
            {"nome": "Daniel", "email": "daniel.vossos@ergondata.com.br"}
        ],
        processing_status_message="Teste"
    )
    create_queue_item_response = qi_controller.create_queue_item(create_queue_item_request)

update_task_execution_request = UpdateTaskExecutionRequestPayload(
    task_execution_status_id="success"
)
controller.update_task_execution(params=update_task_execution_request)
'''

auth = AuthRequestPayload(
    username=os.getenv('WORKER_API_USERNAME'),
    password=os.getenv('WORKER_API_PASSWORD'),
    client_id=os.getenv('WORKER_API_CLIENT_ID')
)

api_client = AuthController(auth=auth, timeout=1000)
tke_controller = TaskExecutionController(api_client=api_client)

create_task_execution_request = CreateTaskExecutionRequestPayload(
    task_id="c2f8e19e-fac1-4f48-8292-e2861cb67b87",
    dev_mode=True
)
create_task_execution_response = tke_controller.create_task_execution(create_task_execution_request)
tke_log_controller = TaskExecutionLogController(api_client=api_client)

if create_task_execution_response.status == "error":
    reset_task_execution_response = tke_controller.reset_task_execution()
    create_task_execution_response = tke_controller.create_task_execution(create_task_execution_request)

qi_controller = QueueItemController(api_client=api_client)


while True:

    create_task_execution_log_request = CreateTaskExecutionLogRequestPayload(
        log_type="info",
        log_message="Getting next queue item"
    )
    create_task_execution_log_response = tke_log_controller.create_task_execution_log(create_task_execution_log_request)

    get_queue_item_request = GetQueueItemRequestPayload(
        queue_id="27b5213b-84eb-4e43-a935-6a261105c520"
    )

    get_queue_item_response = qi_controller.get_queue_item(get_queue_item_request)

    if get_queue_item_response.status == "error":
        reset_queue_item_response = qi_controller.reset_queue_item()
        get_queue_item_response = qi_controller.get_queue_item(get_queue_item_request)

    if get_queue_item_response.data:
        update_queue_item_request = UpdateQueueItemRequestPayload(
            queue_item_id=get_queue_item_response.data.id,
            queue_item_processing_status_message="CASO TBE: 2443943. Motorista: João da Silva",
            queue_item_processing_exception_id="61d8241a-58b7-11ee-8c99-0242ac120002"
        )

        create_task_execution_log_request = CreateTaskExecutionLogRequestPayload(
            log_type="info",
            log_message="Updating queue item"
        )
        create_task_execution_log_response = tke_log_controller.create_task_execution_log(create_task_execution_log_request)
        update_queue_item_response = qi_controller.update_queue_item(update_queue_item_request)
    else:
        break

update_task_execution_request = UpdateTaskExecutionRequestPayload(
    task_execution_status_id="success"
)
update_task_execution_response = tke_controller.update_task_execution(update_task_execution_request)


'''
auth = AuthRequestPayload(
    username="",
    password=""
)

api_client = AuthController(auth=auth, timeout=1000)
tke_controller = TaskExecutionController(api_client=api_client)
qi_controller = QueueItemController(api_client=api_client)

get_queue_items_request = GetQueueItemsRequestPayload(
    queue_id="39208da3-5482-4c57-8698-4119d8749d2d",
    created_at_lte="2023-09-19T11:00:00.000-03:00"
)
get_queue_items_response = qi_controller.get_queue_items(get_queue_items_request)
print(get_queue_items_response)

'''
'''
auth = AuthRequestPayload(
    username="",
    password=""
)
api_client = AuthController(auth=auth, timeout=1000)
tke_controller = TaskExecutionController(api_client=api_client)
tke_log_controller = TaskExecutionLogController(api_client=api_client)

create_task_execution_request = CreateTaskExecutionRequestPayload(
    task_id="6a3ca202-d35c-42fc-b89f-6cf1390a7618",
    dev_mode=True
)
create_task_execution_response = tke_controller.create_task_execution(create_task_execution_request)

if create_task_execution_response.status == "error":
    reset_task_execution_response = tke_controller.reset_task_execution()
    create_task_execution_response = tke_controller.create_task_execution(create_task_execution_request)

tke_log_controller = TaskExecutionLogController(api_client=api_client)

create_task_execution_log_request = CreateTaskExecutionLogRequestPayload(
    log_type="error",
    log_message="Teste"
)
create_task_execution_log_response = tke_log_controller.create_task_execution_log(create_task_execution_log_request)

update_task_execution_request = UpdateTaskExecutionRequestPayload(
    task_execution_status_id="success"
)
update_task_execution_response = tke_controller.update_task_execution(update_task_execution_request)
'''
'''auth = AuthRequestPayload(
    username="",
    password=""
)
api_client = AuthController(auth=auth, timeout=1000)
tke_log_controller = TaskExecutionLogController(api_client=api_client)

get_task_execution_logs_request = GetTaskExecutionLogsRequestPayload(
    task_id="6a3ca202-d35c-42fc-b89f-6cf1390a7618"
)
get_task_execution_logs_response = tke_log_controller.get_task_execution_logs(get_task_execution_logs_request)'''


import os
from dotenv import load_dotenv

from ergondata_executions.controllers.auth.controller import AuthController
from ergondata_executions.controllers.auth.interfaces import *

load_dotenv()

auth_req = AuthRequestPayload(
    username=os.getenv('WORKER_API_USERNAME'),
    password=os.getenv('WORKER_API_PASSWORD'),
    client_id=os.getenv('WORKER_API_CLIENT_ID')
)
auth_controller = AuthController(auth_req, enable_logs=True, timeout=1000)

